summaryrefslogtreecommitdiff
path: root/scripts/saveSample.sh
diff options
context:
space:
mode:
authorYann E. MORIN" <yann.morin.1998@anciens.enib.fr>2007-08-15 16:18:35 (GMT)
committerYann E. MORIN" <yann.morin.1998@anciens.enib.fr>2007-08-15 16:18:35 (GMT)
commit09f0dcc66fbec2f35682d1362f73704d5708ae33 (patch)
treea9e179517ff97a38a8ee848de36571866e1f0f42 /scripts/saveSample.sh
parentecab7e451fbc18d245beb8768a532ff99c6fdf0b (diff)
Change "triplet" (target triplet) to "tuple". That sounds better!
Document overriding the number of // jobs. Some small documentation fixes.
Diffstat (limited to 'scripts/saveSample.sh')
-rwxr-xr-xscripts/saveSample.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/saveSample.sh b/scripts/saveSample.sh
index 4aee0eb..9a3d8fb 100755
--- a/scripts/saveSample.sh
+++ b/scripts/saveSample.sh
@@ -18,8 +18,8 @@ rm -f "${tmp_log_file}"
CT_TestOrAbort "Configuration file not found. Please create one." -f "${CT_TOP_DIR}/.config"
. "${CT_TOP_DIR}/.config"
-# Target triplet: CT_TARGET needs a little love:
-CT_DoBuildTargetTriplet
+# Target tuple: CT_TARGET needs a little love:
+CT_DoBuildTargetTuple
# Kludge: if any of the config options needs either CT_TARGET or CT_TOP_DIR,
# re-parse them: